/*
 * SmartcardioNFC - a library providing a smartcardio implementation for NFC on Android
 *
 * Copyright (C) 2017 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH <info@gematik.de> +49 30 40041-0
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.gematik.security.nfcCard;

import android.app.Activity;

import java.security.AccessController;
import java.security.PrivilegedAction;
import java.security.Provider;

import javax.smartcardio.CardTerminals;
import javax.smartcardio.TerminalFactorySpi;

/**
 * A security provider for NFC on Android.
 */
public final class NfcHealthCardProvider extends Provider {

    public NfcHealthCardProvider() {
        super("NfcHealthCardProvider", 1.0d, "nfc health card provider");
        AccessController.doPrivileged(new PrivilegedAction<Void>() {
            public Void run() {
                put("TerminalFactory.GematikNfcHealthCard", NfcHealthCardProvider.Factory.class.getName());
                return null;
            }
        });
    }

    public static final class Factory extends TerminalFactorySpi {
        private Activity activity = null;
        public Factory(Object obj) {
            if (obj != null && (obj instanceof Activity)) {
                activity  = (Activity)obj;
            }else{
                throw new IllegalArgumentException("NfcHealthCardProvider factory requires context");
            }
        }

        protected CardTerminals engineTerminals() {
            return new NfcCardTerminals(activity);
        }
    }
}

